@@ -92,7 +92,7 @@ create_default_duckdb_connection <- function() {
   con
 }
 
-duckdb_rel_from_df <- function(df) {
+duckdb_rel_from_df <- function(df, call = caller_env()) {
   # FIXME: make generic
   stopifnot(is.data.frame(df))
 
@@ -114,7 +114,7 @@ duckdb_rel_from_df <- function(df) {
     df <- as_duckplyr_df_impl(df)
   }
 
-  out <- check_df_for_rel(df)
+  out <- check_df_for_rel(df, call)
 
   meta_rel_register_df(out, df)
 
@@ -226,8 +226,6 @@ rel_to_df.duckdb_relation <- function(
   prudence_parsed <- prudence_parse(prudence)
   out <- duckdb$rel_to_altrep(
     rel,
-    # FIXME: Remove allow_materialization with duckdb >= 1.2.0
-    allow_materialization = prudence_parsed$allow_materialization,
     n_rows = prudence_parsed$n_rows,
     n_cells = prudence_parsed$n_cells
   )
